@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,7 +58,6 @@ import com.openexchange.caching.Cache;
 import com.openexchange.messaging.json.MessagingMessageParser;
 import com.openexchange.messaging.json.MessagingMessageWriter;
 import com.openexchange.messaging.registry.MessagingServiceRegistry;
-import com.openexchange.session.Session;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.session.ServerSession;
 
@@ -74,19 +73,19 @@ public class MessagingActionFactory implements AJAXActionServiceFactory {
 
     private Map<String, AJAXActionService> actions = null;
 
-    private Cache cache;
+    private final Cache cache;
 
-    private MessagingMessageParser parser;
+    private final MessagingMessageParser parser;
 
-    private MessagingMessageWriter writer;
+    private final MessagingMessageWriter writer;
 
-    private MessagingServiceRegistry registry;
-    
-    
-    public MessagingActionFactory(MessagingServiceRegistry registry, MessagingMessageWriter writer, MessagingMessageParser parser, Cache cache) {
+    private final MessagingServiceRegistry registry;
+
+
+    public MessagingActionFactory(final MessagingServiceRegistry registry, final MessagingMessageWriter writer, final MessagingMessageParser parser, final Cache cache) {
         super();
         actions = new HashMap<String, AJAXActionService>();
-        
+
         actions.put("all", new AllAction(registry, writer, parser, cache));
         actions.put("get", new GetAction(registry, writer, parser, cache));
         actions.put("list", new ListAction(registry, writer, parser, cache));
@@ -94,18 +93,18 @@ public class MessagingActionFactory implements AJAXActionServiceFactory {
         actions.put("send", new SendAction(registry, writer, parser, cache));
         actions.put("update", new UpdateAction(registry, writer, parser, cache));
         actions.put("updates", new UpdatesAction(registry, writer, parser, cache));
-        
+
         this.writer = writer;
         this.parser = parser;
         this.cache = cache;
         this.registry = registry;
-    } 
-    
-    public AJAXActionService createActionService(String action) throws AjaxException {
+    }
+
+    public AJAXActionService createActionService(final String action) throws AjaxException {
         return actions.get(action);
     }
-    
-    public MessagingRequestData wrapRequest(AJAXRequestData req, ServerSession session) {
+
+    public MessagingRequestData wrapRequest(final AJAXRequestData req, final ServerSession session) {
         return new MessagingRequestData(req, session, registry, parser, cache);
     }
 
