@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -69,6 +69,7 @@ import com.openexchange.messaging.MessagingMessage;
 import com.openexchange.messaging.MessagingMessageAccess;
 import com.openexchange.messaging.OrderDirection;
 import com.openexchange.messaging.generic.internet.MimeAddressMessagingHeader;
+import com.openexchange.messaging.json.ManagedFileInputStreamRegistry;
 import com.openexchange.messaging.json.MessagingMessageParser;
 import com.openexchange.messaging.json.cacheing.CacheingMessageAccess;
 import com.openexchange.messaging.registry.MessagingServiceRegistry;
@@ -76,29 +77,30 @@ import com.openexchange.tools.session.ServerSession;
 
 /**
  * Represents a request to the messaging subsystem. The class contains common parsing methods for arguments.
- * 
+ *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class MessagingRequestData {
 
-    private AJAXRequestData request;
+    private final AJAXRequestData request;
 
-    private MessagingServiceRegistry registry;
+    private final MessagingServiceRegistry registry;
 
-    private ServerSession session;
+    private final ServerSession session;
 
-    private MessagingMessageParser parser;
+    private final MessagingMessageParser parser;
 
     private MessagingAccountAccess accountAccess;
 
-    private Cache cache;
+    private final Cache cache;
 
     private MessagingMessageAccess messageAccess;
 
-    private Collection<MessagingAccountAccess> closeables = new LinkedList<MessagingAccountAccess>();
+    private final Collection<MessagingAccountAccess> closeables = new LinkedList<MessagingAccountAccess>();
 
-    public MessagingRequestData(AJAXRequestData request, ServerSession session, MessagingServiceRegistry registry, MessagingMessageParser parser, Cache cache) {
+    public MessagingRequestData(final AJAXRequestData request, final ServerSession session, final MessagingServiceRegistry registry, final MessagingMessageParser parser, final Cache cache) {
+        super();
         this.request = request;
         this.registry = registry;
         this.session = session;
@@ -106,42 +108,43 @@ public class MessagingRequestData {
         this.cache = cache;
     }
 
-    public MessagingRequestData(AJAXRequestData request, ServerSession session, MessagingServiceRegistry registry, MessagingMessageParser parser) {
+    public MessagingRequestData(final AJAXRequestData request, final ServerSession session, final MessagingServiceRegistry registry, final MessagingMessageParser parser) {
         this(request, session, registry, parser, null);
     }
 
-    public MessagingMessageAccess getMessageAccess(String messagingService, int account) throws MessagingException {
-        MessagingAccountAccess access = registry.getMessagingService(messagingService).getAccountAccess(account, session);
+    public MessagingMessageAccess getMessageAccess(final String messagingService, final int account, final int user, final int cid) throws MessagingException {
+        final MessagingAccountAccess access = registry.getMessagingService(messagingService, user, cid).getAccountAccess(account, session);
         if (!access.isConnected()) {
             access.connect();
             mustClose(access);
         }
-
         return wrap(access.getMessageAccess(), messagingService, account);
     }
 
-    private void mustClose(MessagingAccountAccess access) {
+    private void mustClose(final MessagingAccountAccess access) {
         closeables.add(access);
     }
 
     /**
      * Tries to get a message access for the messaging service and account ID as given in the request parameters
-     * 
+     * @param user
+     * @param cid
+     *
      * @throws MessagingException If parameters 'messagingService' or 'account' are missing
      */
-    public MessagingMessageAccess getMessageAccess() throws MessagingException {
+    public MessagingMessageAccess getMessageAccess(final int user, final int cid) throws MessagingException {
         if (messageAccess != null) {
             return messageAccess;
         }
-        MessagingMessageAccess access = getAccountAccess().getMessageAccess();
+        final MessagingMessageAccess access = getAccountAccess(user, cid).getMessageAccess();
         return messageAccess = wrap(access, getMessagingServiceId(), getAccountID());
     }
 
-    public MessagingAccountAccess getAccountAccess() throws MessagingException {
+    public MessagingAccountAccess getAccountAccess(final int user, final int cid) throws MessagingException {
         if (accountAccess != null) {
             return accountAccess;
         }
-        accountAccess = registry.getMessagingService(getMessagingServiceId()).getAccountAccess(getAccountID(), session);
+        accountAccess = registry.getMessagingService(getMessagingServiceId(), user, cid).getAccountAccess(getAccountID(), session);
 
         if (!accountAccess.isConnected()) {
             accountAccess.connect();
@@ -163,15 +166,15 @@ public class MessagingRequestData {
         }
     }
 
-    private void missingParameter(String string) throws MessagingException {
+    private void missingParameter(final String string) throws MessagingException {
         throw MessagingExceptionCodes.MISSING_PARAMETER.create(string);
     }
 
     /**
      * Tries to retrieve the value of a given parameter, failing with a MessagingException if the parameter was not sent.
      */
-    public String requireParameter(String string) throws MessagingException {
-        String parameter = request.getParameter(string);
+    public String requireParameter(final String string) throws MessagingException {
+        final String parameter = request.getParameter(string);
         if (parameter == null) {
             missingParameter(string);
         }
@@ -180,7 +183,7 @@ public class MessagingRequestData {
 
     /**
      * Reads and parses the 'account' parameter.
-     * 
+     *
      * @throws MessagingException - When the 'account' parameter was not set or is not a valid integer.
      */
     public int getAccountID() throws MessagingException {
@@ -188,17 +191,17 @@ public class MessagingRequestData {
             return getLongFolder().getAccount();
         }
 
-        String parameter = requireParameter("account");
+        final String parameter = requireParameter("account");
         try {
             return Integer.parseInt(parameter);
-        } catch (NumberFormatException x) {
+        } catch (final NumberFormatException x) {
             throw MessagingExceptionCodes.INVALID_PARAMETER.create("account", parameter);
         }
     }
 
     /**
      * Reads the 'folder' parameter, failing when it is not set.
-     * 
+     *
      * @throws MessagingException - When the 'folder' parameter is not set.
      */
     public String getFolderId() throws MessagingException {
@@ -211,18 +214,18 @@ public class MessagingRequestData {
     /**
      * Reads and parses the 'columns' parameter. Fails when 'columns' is not set or if it contains an unknown value. Columns are a string
      * separated list of MessagingField names.
-     * 
+     *
      * @return An array of MessagingFields corresponding to the comma-separated list given in the 'columns' parameter.
      * @throws MessagingException - When the 'columns' parameter was not set or contains an illegal value.
      */
     public MessagingField[] getColumns() throws MessagingException {
-        String parameter = requireParameter("columns");
+        final String parameter = requireParameter("columns");
         if (parameter == null) {
             return new MessagingField[0];
         }
 
-        String[] columnList = parameter.split("\\s*,\\s*");
-        MessagingField[] fields = MessagingField.getFields(columnList);
+        final String[] columnList = parameter.split("\\s*,\\s*");
+        final MessagingField[] fields = MessagingField.getFields(columnList);
         for (int i = 0; i < fields.length; i++) {
             if (fields[i] == null) {
                 throw MessagingExceptionCodes.INVALID_PARAMETER.create("columns", columnList[i]);
@@ -234,15 +237,15 @@ public class MessagingRequestData {
     /**
      * Retrieves and parses the 'sort' parameter, turning it into a MessagingField. Returns <code>null</code> when 'sort' is unset. Fails
      * when 'sort' contains an unknown MessagingField.
-     * 
+     *
      * @throws MessagingException - When the 'sort' parameter contains an illegal value.
      */
     public MessagingField getSort() throws MessagingException {
-        String parameter = request.getParameter("sort");
+        final String parameter = request.getParameter("sort");
         if (parameter == null) {
             return null;
         }
-        MessagingField field = MessagingField.getField(parameter);
+        final MessagingField field = MessagingField.getField(parameter);
         if (field == null) {
             throw MessagingExceptionCodes.INVALID_PARAMETER.create("sort", parameter);
         }
@@ -252,24 +255,24 @@ public class MessagingRequestData {
     /**
      * Retrieves and parses the 'order' parameter. Returns <code>null</code> when 'order' is not set. Fails when 'order' contains neither
      * 'desc' and 'asc'. Matches case-insensitively.
-     * 
+     *
      * @throws MessagingException - When 'order' contains an illegal value.
      */
     public OrderDirection getOrder() throws MessagingException {
-        String parameter = request.getParameter("order");
+        final String parameter = request.getParameter("order");
         if (parameter == null) {
             return null;
         }
         try {
             return OrderDirection.valueOf(OrderDirection.class, parameter.toUpperCase());
-        } catch (IllegalArgumentException x) {
+        } catch (final IllegalArgumentException x) {
             throw MessagingExceptionCodes.INVALID_PARAMETER.create("order", parameter);
         }
     }
 
     /**
      * Retrieves the given 'id' parameter. Fails when the 'id' parameter is unset.
-     * 
+     *
      * @throws MessagingException - When the 'id' parameter is unset.
      */
     public String getId() throws MessagingException {
@@ -279,11 +282,11 @@ public class MessagingRequestData {
     /**
      * Retrieves and parses the 'peek' parameter. Returns 'false' when 'peek' is not set. Fails when 'peek' contains neither 'true' nor
      * 'false'. Matches case insensitively.
-     * 
+     *
      * @throws MessagingException - When 'peek' contains an illegal value.
      */
     public boolean getPeek() throws MessagingException {
-        String parameter = request.getParameter("peek");
+        final String parameter = request.getParameter("peek");
         if (parameter == null) {
             return false;
         }
@@ -298,7 +301,7 @@ public class MessagingRequestData {
 
     /**
      * Retrieves the 'messageAction' parameter. Fails when 'messageAction' was not set.
-     * 
+     *
      * @return
      * @throws MessagingException - When 'messageAction' was not set.
      */
@@ -307,21 +310,21 @@ public class MessagingRequestData {
     }
 
     public MessagingMessage getMessage() throws MessagingException, JSONException, IOException {
-        Object data = request.getData();
+        final Object data = request.getData();
         if (data == null) {
             return null;
         }
         if (!JSONObject.class.isInstance(data)) {
             throw MessagingExceptionCodes.INVALID_PARAMETER.create("body", data.toString());
         }
-        return parser.parse((JSONObject) data, null);
+        return parser.parse((JSONObject) data, ManagedFileInputStreamRegistry.getInstance(), request.getRemoteAddress());
     }
 
     /**
      * Determines if the given parameters were set in the request.
      */
-    public boolean isset(String... params) {
-        for (String param : params) {
+    public boolean isset(final String... params) {
+        for (final String param : params) {
             if (null == request.getParameter(param)) {
                 return false;
             }
@@ -332,18 +335,20 @@ public class MessagingRequestData {
     /**
      * Retrieves the MessagingAccountTransport that matches the parameters 'messagingService' and 'account'. Fails when either of the
      * parameters has not been set.
+     * @param user
+     * @param cid
      */
-    public MessagingAccountTransport getTransport() throws MessagingException {
-        return registry.getMessagingService(getMessagingServiceId()).getAccountTransport(getAccountID(), session);
+    public MessagingAccountTransport getTransport(final int user, final int cid) throws MessagingException {
+        return registry.getMessagingService(getMessagingServiceId(), user, cid).getAccountTransport(getAccountID(), session);
     }
 
     /**
      * Retrieves and parses the 'recipients' parameter. May return null, if no recipients were set.
-     * 
+     *
      * @throws MessagingException
      */
     public Collection<MessagingAddressHeader> getRecipients() throws MessagingException {
-        String parameter = request.getParameter("recipients");
+        final String parameter = request.getParameter("recipients");
         if (parameter == null) {
             return null;
         }
@@ -352,14 +357,14 @@ public class MessagingRequestData {
 
     /**
      * Tries to either parse the folder in its long form or assemble it from the content
-     * 
+     *
      * @throws MessagingException
      */
     public MessagingFolderAddress getLongFolder() throws MessagingException {
         if (hasLongFolder()) {
             return MessagingFolderAddress.parse(request.getParameter("folder"));
         } else if (isset("messagingService", "account", "folder")) {
-            MessagingFolderAddress address = new MessagingFolderAddress();
+            final MessagingFolderAddress address = new MessagingFolderAddress();
             address.setMessagingService(getMessagingServiceId());
             address.setAccount(getAccountID());
             address.setFolder(getFolderId());
@@ -373,19 +378,19 @@ public class MessagingRequestData {
     }
 
     public List<MessageAddress> getMessageAddresses() throws JSONException, MessagingException {
-        Object data = request.getData();
+        final Object data = request.getData();
         if (data == null) {
             throw MessagingExceptionCodes.MISSING_PARAMETER.create("body");
         }
         if (!JSONArray.class.isInstance(data)) {
             throw MessagingExceptionCodes.INVALID_PARAMETER.create("body", data.toString());
         }
-        JSONArray idsJSON = (JSONArray) data;
+        final JSONArray idsJSON = (JSONArray) data;
 
-        List<MessageAddress> addresses = new ArrayList<MessageAddress>(idsJSON.length());
+        final List<MessageAddress> addresses = new ArrayList<MessageAddress>(idsJSON.length());
 
         for (int i = 0, size = idsJSON.length(); i < size; i++) {
-            JSONObject pair = idsJSON.getJSONObject(i);
+            final JSONObject pair = idsJSON.getJSONObject(i);
             addresses.add(new MessageAddress(pair.getString("folder"), pair.getString("id")));
         }
 
@@ -396,15 +401,15 @@ public class MessagingRequestData {
         return getMessagingServiceId() + "://" + getAccountID();
     }
 
-    public MessagingMessageAccess wrap(MessagingMessageAccess messageAccess2, String service, int account) {
+    public MessagingMessageAccess wrap(final MessagingMessageAccess messageAccess2, final String service, final int account) {
         if (cache == null) {
             return messageAccess2;
         }
-        return new CacheingMessageAccess(messageAccess2, cache, service + "://" + account, session);
+        return new CacheingMessageAccess(messageAccess2, cache, new StringBuilder(service).append("://").append(account).toString(), session);
     }
 
     public void cleanUp() {
-        for (MessagingAccountAccess closeable : closeables) {
+        for (final MessagingAccountAccess closeable : closeables) {
             closeable.close();
         }
     }
