@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,15 +64,15 @@ public class ServicesActionFactory implements AJAXActionServiceFactory {
 
     public static ServicesActionFactory INSTANCE; // Initialized in Activator
 
-    private Map<String, AJAXActionService> actions;
+    private final Map<String, AJAXActionService> actions;
 
-    public ServicesActionFactory(MessagingServiceRegistry registry) {
-        this.actions = new HashMap<String, AJAXActionService>();
+    public ServicesActionFactory(final MessagingServiceRegistry registry) {
+        actions = new HashMap<String, AJAXActionService>();
         actions.put("all", new AllAction(registry));
         actions.put("get", new GetAction(registry));
     }
 
-    public AJAXActionService createActionService(String action) {
+    public AJAXActionService createActionService(final String action) {
         return actions.get(action);
     }
 }
