@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -53,9 +53,12 @@ import junit.framework.TestCase;
 import org.json.JSONArray;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.groupware.contexts.SimContext;
+import com.openexchange.groupware.ldap.SimUser;
 import com.openexchange.messaging.MessagingException;
 import com.openexchange.messaging.SimMessagingService;
 import com.openexchange.messaging.registry.SimMessagingServiceRegistry;
+import com.openexchange.tools.session.SimServerSession;
 
 /**
  * {@link AllActionTest}
@@ -66,46 +69,46 @@ public class AllActionTest extends TestCase {
 
     // Success Case
     public void testSuccess() throws AbstractOXException {
-        SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
+        final SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
 
-        SimMessagingService messagingService = new SimMessagingService();
+        final SimMessagingService messagingService = new SimMessagingService();
         messagingService.setId("com.openexchange.test");
 
         registry.add(messagingService);
 
-        AllAction action = new AllAction(registry);
+        final AllAction action = new AllAction(registry);
 
-        AJAXRequestResult result = action.perform(null, null);
+        final AJAXRequestResult result = action.perform(null, new SimServerSession(new SimContext(1), new SimUser(), null));
 
         assertNotNull(result);
 
-        Object resultObject = result.getResultObject();
+        final Object resultObject = result.getResultObject();
         assertNotNull(resultObject);
 
         assertTrue(JSONArray.class.isInstance(resultObject));
 
-        JSONArray all = (JSONArray) resultObject;
+        final JSONArray all = (JSONArray) resultObject;
         assertEquals(1, all.length());
     }
 
     // Error Cases
 
     public void testMessagingException() throws AbstractOXException {
-        SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
+        final SimMessagingServiceRegistry registry = new SimMessagingServiceRegistry();
         registry.setException(new MessagingException(null, -1, null, null));
 
-        SimMessagingService messagingService = new SimMessagingService();
+        final SimMessagingService messagingService = new SimMessagingService();
         messagingService.setId("com.openexchange.test");
 
         registry.add(messagingService);
 
-        AllAction action = new AllAction(registry);
+        final AllAction action = new AllAction(registry);
 
         try {
-            AJAXRequestResult result = action.perform(null, null);
+        final AJAXRequestResult result = action.perform(null, new SimServerSession(new SimContext(1), new SimUser(), null));
             fail("Should not swallow exceptions");
             assertNull(result);
-        } catch (MessagingException x) {
+        } catch (final MessagingException x) {
             // Success
         }
     }
